import { WebMercator } from "../projection/web-mercator";
import { Subject } from "../util/subject";
/**
 * 图层基类
 */
export class Layer extends Subject {
    /**
     * 创建图层
     */
    constructor() {
        super([]);
        /**
         * 图层可见设置
         */
        this._visible = true;
        /**
         * 图层可交互设置
         */
        this._interactive = true;
        /**
         * 图层顺序（z-index）
         * @remarks
         * TODO: marker的异步加载，会影响绘制顺序
         */
        this._index = 0; //z-index
    }
    /**
     * 图层是否可见
     */
    get visible() {
        return this._visible;
    }
    /**
     * 图层可见设置
     */
    set visible(value) {
        this._visible = value;
    }
    /**
     * 图层是否可交互
     */
    get interactive() {
        return this._interactive;
    }
    /**
     * 图层可交互设置
     */
    set interactive(value) {
        this._interactive = value;
    }
    /**
     * 图层顺序
     */
    get index() {
        return this._index;
    }
    /**
     * 图层顺序设置
     */
    set index(value) {
        this._index = value;
    }
    /**
     * 绘制图层
     * @param {CanvasRenderingContext2D} ctx - 绘图上下文
     * @param {Projection} projection - 坐标投影转换
     * @param {Bound} extent - 当前可视范围
     * @param {number} zoom - 当前缩放级别
     */
    draw(ctx, projection = new WebMercator(), extent = projection.bound, zoom = 10) { }
    ;
    //animate(elapsed, ctx: CanvasRenderingContext2D, projection: Projection = new WebMercator(), extent: Bound = projection.bound, zoom: number = 10) {};
    /**
     * 图层交互
     * @remarks 当前鼠标是否落入该图层某要素
     * @param {number} screenX - 鼠标屏幕坐标X
     * @param {number} screenX - 鼠标屏幕坐标Y
     * @param {Projection} projection - 坐标投影转换
     * @param {Bound} extent - 当前可视范围
     * @param {number} zoom - 当前缩放级别
     * @param {string} event - 当前事件名称
     * @return {boolean} 是否落入
     */
    contain(screenX, screenY, projection = new WebMercator(), extent = projection.bound, zoom = 10, event = undefined) { return false; }
}
